@@ -39,6 +39,7 @@ using namespace CppUtilities::EscapeCodes;
 
 namespace Data {
 
+#ifndef LIB_SYNCTHING_CONNECTOR_MOCKED
 /*!
  * \brief Returns the QNetworkAccessManager instance used by SyncthingConnection instances.
  */
@@ -47,6 +48,7 @@ QNetworkAccessManager &networkAccessManager()
     static auto networkAccessManager = new QNetworkAccessManager;
     return *networkAccessManager;
 }
+#endif
 
 /*!
  * \class SyncthingConnection
@@ -267,8 +269,7 @@ void SyncthingConnection::setPausingOnMeteredConnection(bool pausingOnMeteredCon
             // initialize handling of metered connections
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
             if (!m_handlingMeteredConnectionInitialized) {
-                QNetworkInformation::loadBackendByFeatures(QNetworkInformation::Feature::Metered);
-                if (const auto *const networkInformation = QNetworkInformation::instance()) {
+                if (const auto *const networkInformation = loadNetworkInformationBackendForMetered()) {
                     QObject::connect(networkInformation, &QNetworkInformation::isMeteredChanged, this, &SyncthingConnection::handleMeteredConnection);
                 }
             }
@@ -1072,7 +1073,7 @@ void SyncthingConnection::emitError(const QString &message, const QJsonParseErro
 }
 
 /*!
- * \brief Internally called to emit a network error (server replied error code are connection or server could not be reached at all).
+ * \brief Internally called to emit a network error (server replied error code or server could not be reached at all).
  */
 void SyncthingConnection::emitError(const QString &message, SyncthingErrorCategory category, QNetworkReply *reply)
 {
@@ -1082,6 +1083,19 @@ void SyncthingConnection::emitError(const QString &message, SyncthingErrorCatego
     emit error(message + reply->errorString(), category, reply->error(), reply->request(), reply->bytesAvailable() ? reply->readAll() : QByteArray());
 }
 
+/*!
+ * \brief Internally called to emit a network error for a specific request (server replied error code or server could not be reached at all).
+ * \remarks The \a message is supposed to already contain the error string of the reply.
+ */
+void SyncthingConnection::emitError(const QString &message, QNetworkReply *reply)
+{
+    if (loggingFlags() & SyncthingConnectionLoggingFlags::ApiReplies) {
+        cerr << Phrases::Error << "Syncthing API error: " << message.toLocal8Bit().data() << reply->errorString().toLocal8Bit().data() << endl;
+    }
+    emit error(message, SyncthingErrorCategory::SpecificRequest, reply->error(), reply->request(),
+        reply->bytesAvailable() ? reply->readAll() : QByteArray());
+}
+
 /*!
  * \brief Internally called to emit myIdChanged() signal.
  */
