@@ -5,6 +5,7 @@
 #include "./syncthingconnectionstatus.h"
 #include "./syncthingdev.h"
 #include "./syncthingdir.h"
+#include "./utils.h"
 
 #include <c++utilities/misc/flagenumclass.h>
 
@@ -17,11 +18,6 @@
 #include <QSslError>
 #include <QTimer>
 
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 3, 0))
-#include <QNetworkInformation>
-#define SYNCTHINGCONNECTION_SUPPORT_METERED
-#endif
-
 #include <cstdint>
 #include <functional>
 #include <limits>
@@ -53,19 +49,70 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingLogEntry {
     QString message;
 };
 
-enum class SyncthingItemType { Unknown, File, Directory };
+enum class SyncthingItemType {
+    Unknown, /**< the type is unknown */
+    File, /**< the item is a regular file */
+    Directory, /**< the item is a directory */
+    Symlink, /**< the item is a symlink (pointing to a file or directory) */
+    Error, /**< the item represents an error message (e.g. the API query ran into an error); used by SyncthingFileModel */
+    Loading, /**< the item represents a loading indication; used by SyncthingFileModel */
+};
 
 struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingItem {
+    /// \brief The matching ignore pattern was not initialized for this item.
+    static constexpr auto ignorePatternNotInitialized = std::numeric_limits<std::size_t>::max();
+    /// \brief The item did not match any of the current ignore patterns.
+    static constexpr auto ignorePatternNoMatch = ignorePatternNotInitialized - 1;
+
+    /// \brief The name of the filesystem item or error/loading message in case of those item types.
     QString name;
-    CppUtilities::DateTime modificationTime;
+    /// \brief The modification time. Only populated with a meaningful value for files and directories.
+    CppUtilities::DateTime modificationTime = CppUtilities::DateTime();
+    /// \brief The file size. Only populated with a meaningful value for files.
     std::size_t size = std::size_t();
+    /// \brief The type of the item.
     SyncthingItemType type = SyncthingItemType::Unknown;
-    std::vector<SyncthingItem> children;
-    SyncthingItem *parent = nullptr; // not populated but might be set as needed (take care in case the pointer gets invalidated)
+    /// \brief The child items, if populated as indicated by childrenPopulated.
+    std::vector<std::unique_ptr<SyncthingItem>> children;
+    /// \brief The parent item; not populated by default but might be set as needed (take care in case the pointer gets invalidated).
+    SyncthingItem *parent = nullptr;
+    /// \brief The path of the item; not populated by default but might be set as needed.
+    QString path;
+    /// \brief The index of the item within its parent.
     std::size_t index = std::size_t();
-    int level = 0; // the level of nesting, does *not* include levels of the prefix
-    bool childrenPopulated = false; // populated depending on requested level
-    bool checked = false; // not populated but might be set to flag an item for some mass-action
+    /// \brief The index of the ignore pattern (in the current list of ignore patterns) this item matches.
+    /// \remarks Not populated by default.
+    std::size_t ignorePattern = ignorePatternNotInitialized;
+    /// \brief The level of nesting, does *not* include levels of the prefix.
+    int level = 0;
+    /// \brief Whether children are populated (depends on the requested level).
+    bool childrenPopulated = false;
+    /// \brief Whether the item is "checked"; not set by default but might be set to flag an item for some mass-action.
+    Qt::CheckState checked = Qt::Unchecked;
+    /// \brief Whether the item is present in the Syncthing database.
+    bool existsInDb = true;
+    /// \brief Whether the item is present in the local file system.
+    bool existsLocally = false;
+
+    bool isFilesystemItem() const;
+};
+
+/// \brief Returns whether the item is actually a filesystem item.
+inline bool SyncthingItem::isFilesystemItem() const
+{
+    switch (type) {
+    case Data::SyncthingItemType::File:
+    case Data::SyncthingItemType::Directory:
+    case Data::SyncthingItemType::Symlink:
+        return true;
+    default:
+        return false;
+    }
+}
+
+struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingIgnores {
+    QStringList ignore;
+    QStringList expanded;
 };
 
 class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
@@ -119,6 +166,11 @@ public:
         SyncthingConnectionLoggingFlags loggingFlags = SyncthingConnectionLoggingFlags::FromEnvironment, QObject *parent = nullptr);
     ~SyncthingConnection() override;
 
+    struct QueryResult {
+        QNetworkReply *reply = nullptr;
+        QMetaObject::Connection connection;
+    };
+
     // getter/setter for
     const QString &syncthingUrl() const;
     void setSyncthingUrl(const QString &url);
@@ -257,8 +309,10 @@ public Q_SLOTS:
 
 public:
     // methods to GET or POST information from/to Syncthing (non-slots)
-    QMetaObject::Connection browse(
-        const QString &dirId, const QString &prefix, int level, std::function<void(std::vector<SyncthingItem> &&)> &&callback);
+    QueryResult browse(const QString &dirId, const QString &prefix, int level,
+        std::function<void(std::vector<std::unique_ptr<SyncthingItem>> &&, QString &&)> &&callback);
+    QueryResult ignores(const QString &dirId, std::function<void(SyncthingIgnores &&, QString &&)> &&callback);
+    QueryResult setIgnores(const QString &dirId, const SyncthingIgnores &ignores, std::function<void(QString &&)> &&callback);
 
 Q_SIGNALS:
     void newConfig(const QJsonObject &rawConfig);
@@ -361,6 +415,7 @@ private Q_SLOTS:
     void emitNotification(CppUtilities::DateTime when, const QString &message);
     void emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response = QByteArray());
     void emitError(const QString &message, Data::SyncthingErrorCategory category, QNetworkReply *reply);
+    void emitError(const QString &message, QNetworkReply *reply);
     void emitMyIdChanged(const QString &newId);
     void emitTildeChanged(const QString &newTilde, const QString &newPathSeparator);
     void emitDirStatisticsChanged();
@@ -373,7 +428,9 @@ private Q_SLOTS:
 
 private:
     // handler to evaluate results from request...() methods
-    void readBrowse(const QString &dirId, int levels, std::function<void(std::vector<SyncthingItem> &&)> &&callback);
+    void readBrowse(const QString &dirId, int levels, std::function<void(std::vector<std::unique_ptr<SyncthingItem>> &&, QString &&)> &&callback);
+    void readIgnores(const QString &dirId, std::function<void(SyncthingIgnores &&, QString &&)> &&callback);
+    void readSetIgnores(const QString &dirId, std::function<void(QString &&)> &&callback);
 
     // internal helper methods
     struct Reply {
