@@ -35,12 +35,14 @@ protected:
     void invalidateTopLevelIndicies(const QVector<int> &affectedRoles);
     void invalidateNestedIndicies(const QVector<int> &affectedRoles);
     void invalidateAllIndicies(const QVector<int> &affectedRoles, const QModelIndex &parentIndex = QModelIndex());
+    void invalidateAllIndicies(const QVector<int> &affectedRoles, int column, const QModelIndex &parentIndex = QModelIndex());
 
 private Q_SLOTS:
     virtual void handleConfigInvalidated();
     virtual void handleNewConfigAvailable();
     virtual void handleStatusIconsChanged();
     virtual void handleForkAwesomeIconsChanged();
+    virtual void handleBrightColorsChanged();
 
 protected:
     Data::SyncthingConnection &m_connection;
