@@ -5,6 +5,8 @@
 
 #include <QWidget>
 
+#include <functional>
+
 QT_FORWARD_DECLARE_CLASS(QTextBrowser)
 QT_FORWARD_DECLARE_CLASS(QVBoxLayout)
 
@@ -19,10 +21,11 @@ namespace QtGui {
 class SYNCTHINGWIDGETS_EXPORT TextViewDialog : public QWidget {
     Q_OBJECT
 public:
-    TextViewDialog(const QString &title = QString(), QWidget *parent = nullptr);
+    explicit TextViewDialog(const QString &title = QString(), QWidget *parent = nullptr);
 
     QTextBrowser *browser();
     QVBoxLayout *layout();
+    void setCloseHandler(std::function<bool(TextViewDialog *)> &&closeHandler);
     static TextViewDialog *forLogEntries(Data::SyncthingConnection &connection);
     static TextViewDialog *forLogEntries(const std::vector<Data::SyncthingLogEntry> &logEntries, const QString &title = QString());
 
@@ -31,12 +34,14 @@ Q_SIGNALS:
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
 
 private:
     void showLogEntries(const std::vector<Data::SyncthingLogEntry> &logEntries);
 
     QTextBrowser *m_browser;
     QVBoxLayout *m_layout;
+    std::function<bool(TextViewDialog *)> m_closeHandler;
 };
 
 inline QTextBrowser *TextViewDialog::browser()
@@ -49,6 +54,11 @@ inline QVBoxLayout *TextViewDialog::layout()
     return m_layout;
 }
 
+inline void TextViewDialog::setCloseHandler(std::function<bool(TextViewDialog *)> &&closeHandler)
+{
+    m_closeHandler = std::move(closeHandler);
+}
+
 } // namespace QtGui
 
 #endif // SYNCTHINGWIDGETS_TEXTVIEWDIALOG_H
