@@ -91,7 +91,7 @@ struct SYNCTHINGWIDGETS_EXPORT Launcher {
 #else
         QStringLiteral("syncthing");
 #endif
-    QString syncthingArgs = QStringLiteral("-no-browser -no-restart -logflags=3");
+    QString syncthingArgs = QStringLiteral("serve --no-browser --logflags=3");
     QHash<QString, ToolParameter> tools;
     bool considerForReconnect = false;
     bool showButton = false;
@@ -102,6 +102,7 @@ struct SYNCTHINGWIDGETS_EXPORT Launcher {
         QString configDir;
         QString dataDir;
         ::LibSyncthing::LogLevel logLevel = ::LibSyncthing::LogLevel::Info;
+        bool expandPaths = false;
     } libSyncthing;
 #endif
 
@@ -127,6 +128,7 @@ struct SYNCTHINGWIDGETS_EXPORT Systemd {
     bool systemUnit = false;
     bool showButton = false;
     bool considerForReconnect = false;
+    bool stopOnMeteredConnection = false;
 
     struct SYNCTHINGWIDGETS_EXPORT ServiceStatus {
         bool relevant = false;
