@@ -708,17 +708,17 @@ QWidget *IconsOptionPage::setupWidget()
     auto *const presetsMenu = new QMenu(widget);
     presetsMenu->addAction(QCoreApplication::translate("QtGui::IconsOptionPageBase", "Colorful background with gradient (default)"), widget, [this] {
         m_settings = Data::StatusIconSettings();
-        update();
+        update(true);
     });
     presetsMenu->addAction(
         QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and dark foreground (for bright themes)"), widget, [this] {
             m_settings = Data::StatusIconSettings(Data::StatusIconSettings::BrightTheme{});
-            update();
+            update(true);
         });
     presetsMenu->addAction(
         QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and bright foreground (for dark themes)"), widget, [this] {
             m_settings = Data::StatusIconSettings(Data::StatusIconSettings::DarkTheme{});
-            update();
+            update(true);
         });
 
     // setup additional buttons
@@ -763,9 +763,14 @@ bool IconsOptionPage::apply()
     return true;
 }
 
-void IconsOptionPage::update()
+void IconsOptionPage::update(bool preserveSize)
 {
-    ui()->renderingSizeSlider->setValue(std::max(m_settings.renderSize.width(), m_settings.renderSize.height()));
+    if (preserveSize) {
+        const auto size = ui()->renderingSizeSlider->value();
+        m_settings.renderSize = QSize(size, size);
+    } else {
+        ui()->renderingSizeSlider->setValue(std::max(m_settings.renderSize.width(), m_settings.renderSize.height()));
+    }
     ui()->thickStrokeWidthCheckBox->setChecked(m_settings.strokeWidth == StatusIconStrokeWidth::Thick);
     for (auto &widgetsForColor : m_widgets) {
         widgetsForColor.colorButtons[0]->setColor(widgetsForColor.setting->backgroundStart);
@@ -813,14 +818,14 @@ QWidget *AutostartOptionPage::setupWidget()
         setAutostartPath(QString());
         reset();
     });
-#if defined(PLATFORM_LINUX) && !defined(PLATFORM_ANDROID)
+#if !defined(SYNCTHINGWIDGETS_AUTOSTART_DISABLED) && defined(PLATFORM_LINUX) && !defined(PLATFORM_ANDROID)
     ui()->platformNoteLabel->setText(QCoreApplication::translate("QtGui::AutostartOptionPage",
         "This is achieved by adding a *.desktop file under <i>~/.config/autostart</i> so the setting only affects the current user."));
-#elif defined(PLATFORM_WINDOWS)
+#elif !defined(SYNCTHINGWIDGETS_AUTOSTART_DISABLED) && defined(PLATFORM_WINDOWS)
     ui()->platformNoteLabel->setText(QCoreApplication::translate("QtGui::AutostartOptionPage",
         "This is achieved by adding a registry key under <i>HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Run</i> so the setting "
         "only affects the current user. Note that the startup entry is invalidated when moving <i>syncthingtray.exe</i>."));
-#elif defined(PLATFORM_MAC)
+#elif !defined(SYNCTHINGWIDGETS_AUTOSTART_DISABLED) && defined(PLATFORM_MAC)
     ui()->platformNoteLabel->setText(QCoreApplication::translate("QtGui::AutostartOptionPage",
         "This is achieved by adding a *.plist file under <i>~/Library/LaunchAgents</i> so the setting only affects the current user."));
 #else
@@ -828,7 +833,7 @@ QWidget *AutostartOptionPage::setupWidget()
         QCoreApplication::translate("QtGui::AutostartOptionPage", "This feature has not been implemented for your platform (yet)."));
     m_unsupported = true;
     ui()->pathWidget->setVisible(false);
-    ui()->autostartCheckBox->setEnabled(false);
+    ui()->autostartCheckBox->setVisible(false);
 #endif
     return widget;
 }
@@ -1119,7 +1124,7 @@ QWidget *LauncherOptionPage::setupWidget()
 
     // hide libsyncthing-controls by default (as the checkbox is unchecked by default)
     for (auto *const lstWidget : std::initializer_list<QWidget *>{ ui()->configDirLabel, ui()->configDirPathSelection, ui()->dataDirLabel,
-             ui()->dataDirPathSelection, ui()->logLevelLabel, ui()->logLevelComboBox }) {
+             ui()->dataDirPathSelection, ui()->logLevelLabel, ui()->logLevelComboBox, ui()->optionsLabel, ui()->expandEnvCheckBox }) {
         lstWidget->setVisible(false);
     }
 
@@ -1191,6 +1196,7 @@ bool LauncherOptionPage::apply()
         settings.libSyncthing.configDir = ui()->configDirPathSelection->lineEdit()->text();
         settings.libSyncthing.dataDir = ui()->dataDirPathSelection->lineEdit()->text();
         settings.libSyncthing.logLevel = static_cast<LibSyncthing::LogLevel>(ui()->logLevelComboBox->currentIndex());
+        settings.libSyncthing.expandPaths = ui()->expandEnvCheckBox->isChecked();
 #endif
         settings.syncthingPath = ui()->syncthingPathSelection->lineEdit()->text();
         settings.syncthingArgs = ui()->argumentsLineEdit->text();
@@ -1220,6 +1226,7 @@ void LauncherOptionPage::reset()
         ui()->configDirPathSelection->lineEdit()->setText(settings.libSyncthing.configDir);
         ui()->dataDirPathSelection->lineEdit()->setText(settings.libSyncthing.dataDir);
         ui()->logLevelComboBox->setCurrentIndex(static_cast<int>(settings.libSyncthing.logLevel));
+        ui()->expandEnvCheckBox->setChecked(settings.libSyncthing.expandPaths);
 #endif
         ui()->syncthingPathSelection->lineEdit()->setText(settings.syncthingPath);
         ui()->argumentsLineEdit->setText(settings.syncthingArgs);
@@ -1426,6 +1433,7 @@ QWidget *SystemdOptionPage::setupWidget()
         QIcon::fromTheme(QStringLiteral("view-refresh"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/view-refresh.svg"))));
     ui()->syncthingUnitLineEdit->addCustomAction(refreshAction);
     if (!m_service) {
+        ui()->stopOnMeteredCheckBox->setHidden(true);
         return widget;
     }
     QObject::connect(refreshAction, &QAction::triggered, m_service, &SyncthingService::reloadAllUnitFiles);
@@ -1434,6 +1442,8 @@ QWidget *SystemdOptionPage::setupWidget()
     QObject::connect(ui()->stopPushButton, &QPushButton::clicked, m_service, &SyncthingService::stop);
     QObject::connect(ui()->enablePushButton, &QPushButton::clicked, m_service, &SyncthingService::enable);
     QObject::connect(ui()->disablePushButton, &QPushButton::clicked, m_service, &SyncthingService::disable);
+    QObject::connect(ui()->stopOnMeteredCheckBox, &QCheckBox::stateChanged, m_service,
+        [s = m_service](int checkState) { s->setStoppingOnMeteredConnection(checkState == Qt::Checked); });
     m_unitChangedConn
         = QObject::connect(ui()->systemUnitCheckBox, &QCheckBox::clicked, m_service, bind(&SystemdOptionPage::handleSystemUnitChanged, this));
     m_descChangedConn
@@ -1445,6 +1455,9 @@ QWidget *SystemdOptionPage::setupWidget()
     if (const auto *optionPageWidget = qobject_cast<OptionPageWidget *>(widget)) {
         QObject::connect(optionPageWidget, &OptionPageWidget::paletteChanged, std::bind(&SystemdOptionPage::updateColors, this));
     }
+    configureMeteredCheckbox(ui()->stopOnMeteredCheckBox, m_service->isNetworkConnectionMetered());
+    QObject::connect(m_service, &SyncthingService::networkConnectionMeteredChanged,
+        std::bind(&configureMeteredCheckbox, ui()->stopOnMeteredCheckBox, std::placeholders::_1));
     return widget;
 }
 
@@ -1457,6 +1470,7 @@ bool SystemdOptionPage::apply()
     systemdSettings.systemUnit = ui()->systemUnitCheckBox->isChecked();
     systemdSettings.showButton = ui()->showButtonCheckBox->isChecked();
     systemdSettings.considerForReconnect = ui()->considerForReconnectCheckBox->isChecked();
+    systemdSettings.stopOnMeteredConnection = ui()->stopOnMeteredCheckBox->isChecked();
     auto result = true;
     if (systemdSettings.showButton && launcherSettings.showButton) {
         errors().append(QCoreApplication::translate("QtGui::SystemdOptionPage",
@@ -1480,6 +1494,7 @@ void SystemdOptionPage::reset()
     ui()->systemUnitCheckBox->setChecked(settings.systemUnit);
     ui()->showButtonCheckBox->setChecked(settings.showButton);
     ui()->considerForReconnectCheckBox->setChecked(settings.considerForReconnect);
+    ui()->stopOnMeteredCheckBox->setChecked(settings.stopOnMeteredConnection);
     if (!m_service) {
         return;
     }
