@@ -207,7 +207,8 @@ void WebPage::insertStyleSheet(const QString &name, const QString &cssCode, bool
 static QString rgba(const QColor &color)
 {
     return QStringLiteral("rgba(%1, %2, %3, %4)")
-        .arg(QString::number(color.red()), QString::number(color.green()), QString::number(color.blue()), QString::number(color.alphaF()));
+        .arg(QString::number(color.red()), QString::number(color.green()), QString::number(color.blue()),
+            QString::number(static_cast<double>(color.alphaF())));
 }
 
 /*!
@@ -223,7 +224,7 @@ void WebPage::styleScrollBars(bool immediate)
 
     // determine colors from palette
     const auto palette = m_view->palette();
-    const auto alphaF = 0.75f;
+    const auto alphaF = static_cast<qreal>(0.75);
     auto highlightColor = palette.color(QPalette::Active, QPalette::Highlight);
     auto highlightColorInactive = QColor::fromHsv(highlightColor.hue(), 0, highlightColor.value());
     highlightColor.setAlphaF(alphaF);
