@@ -28,24 +28,23 @@ DirButtonsItemDelegate::DirButtonsItemDelegate(QObject *parent)
 
 void DirButtonsItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    // use the customization only on top-level rows
+    auto opt = option;
+    initStyleOption(&opt, index);
+    opt.viewItemPosition = QStyleOptionViewItem::OnlyOne;
     if (index.parent().isValid()) {
-        QStyledItemDelegate::paint(painter, option, index);
+        QStyledItemDelegate::paint(painter, opt, index);
     } else {
         // init style options to use drawControl(), except for the text
-        QStyleOptionViewItem opt = option;
-        initStyleOption(&opt, index);
         opt.text.clear();
         opt.features = QStyleOptionViewItem::None;
-        QApplication::style()->drawControl(QStyle::CE_ItemViewItem, &opt, painter);
+        drawBasicItemViewItem(*painter, opt);
 
         // draw text
         auto textRect = QRectF(option.rect);
         textRect.setWidth(textRect.width() - 58);
         QTextOption textOption;
         textOption.setAlignment(opt.displayAlignment);
-        painter->setFont(opt.font);
-        painter->setPen(opt.palette.color(opt.state & QStyle::State_Selected ? QPalette::HighlightedText : QPalette::Text));
+        setupPainterToDrawViewItemText(painter, opt);
         painter->drawText(textRect, displayText(index.data(Qt::DisplayRole), option.locale), textOption);
 
         // draw buttons
