@@ -23,6 +23,7 @@ DirView::DirView(QWidget *parent)
 {
     header()->setSectionResizeMode(QHeaderView::ResizeToContents);
     header()->hide();
+    setItemDelegate(new UnifiedItemDelegate(this));
     setItemDelegateForColumn(1, new DirButtonsItemDelegate(this));
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &DirView::customContextMenuRequested, this, &DirView::showContextMenu);
@@ -108,6 +109,8 @@ void DirView::showContextMenu(const QPoint &position)
                                        QIcon(QStringLiteral(":/icons/hicolor/scalable/places/document-open-remote.svg"))),
                         tr("Browse remote files")),
                 &QAction::triggered, triggerActionForSelectedRow(this, &DirView::browseRemoteFiles));
+            connect(menu.addAction(QIcon::fromTheme(QStringLiteral("selection-symbolic")), tr("Show ignore patterns")), &QAction::triggered,
+                triggerActionForSelectedRow(this, &DirView::showIgnorePatterns));
         }
     }
     showViewMenu(position, *this, menu);
