@@ -17,13 +17,14 @@ public:
     using ModelType = Data::SyncthingDirectoryModel;
     using SortFilterModelType = Data::SyncthingSortFilterModel;
 
-    DirView(QWidget *parent = nullptr);
+    explicit DirView(QWidget *parent = nullptr);
 
 Q_SIGNALS:
     void openDir(const Data::SyncthingDir &dir);
     void scanDir(const Data::SyncthingDir &dir);
     void pauseResumeDir(const Data::SyncthingDir &dir);
     void browseRemoteFiles(const Data::SyncthingDir &dir);
+    void showIgnorePatterns(const Data::SyncthingDir &dir);
 
 protected:
     void mouseReleaseEvent(QMouseEvent *event) override;
