@@ -6,18 +6,30 @@
 #include <QClipboard>
 #include <QGuiApplication>
 #include <QModelIndex>
-#include <QPoint>
+#include <QStyledItemDelegate>
 #include <QTreeView>
 
 #include <functional>
 #include <type_traits>
 
+QT_FORWARD_DECLARE_CLASS(QPainter)
 QT_FORWARD_DECLARE_CLASS(QPoint)
 QT_FORWARD_DECLARE_CLASS(QMenu)
+QT_FORWARD_DECLARE_CLASS(QStyleOptionViewItem)
 
 namespace QtGui {
 
+class UnifiedItemDelegate : public QStyledItemDelegate {
+    Q_OBJECT
+public:
+    explicit UnifiedItemDelegate(QObject *parent);
+
+    void paint(QPainter *, const QStyleOptionViewItem &, const QModelIndex &) const override;
+};
+
 void showViewMenu(const QPoint &position, const QTreeView &view, QMenu &menu);
+void drawBasicItemViewItem(QPainter &painter, const QStyleOptionViewItem &option);
+void setupPainterToDrawViewItemText(QPainter *painter, QStyleOptionViewItem &opt);
 
 inline auto copyToClipboard(const QString &text)
 {
